//******************************************************************************
//! @file       cc1200_rx_sniff_mode_reg_config.h
//! @brief      CC1120 register export from SmartRF Studio
//
//  Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com/
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions
//  are met:
//
//      Redistributions of source code must retain the above copyright
//      notice, this list of conditions and the following disclaimer.
//
//      Redistributions in binary form must reproduce the above copyright
//      notice, this list of conditions and the following disclaimer in the
//      documentation and/or other materials provided with the distribution.
//
//      Neither the name of Texas Instruments Incorporated nor the names of
//      its contributors may be used to endorse or promote products derived
//      from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//*****************************************************************************/

#ifndef CC1200_RX_SNIFF_MODE_REG_CONFIG_H
#define CC1200_RX_SNIFF_MODE_REG_CONFIG_H

#ifdef __cplusplus
extern "C" {
#endif
/******************************************************************************
 * INCLUDES
 */
#include "hal_spi_rf_trxeb.h"
#include "cc120x_spi.h"


/******************************************************************************
 * VARIABLES
 */

// S2-mode RX settings 
// RX filter BW = 208.333
// Address config = No address check
// Packet length = 30
// Symbol rate = 32.768
// Carrier frequency = 868.299866
// Bit rate = 32.768
// Packet bit length = 0
// Whitening = false
// Manchester enable = NO
// Modulation format = 2-FSK
// Packet length mode = FIXED
// Device address = 0
// Deviation = 65.002
// S2-Mode RX settings for CC1200
// Packet Example from EN13757-4:2012 for S-mode, MANCHESTER coding:
// 0F 44 AE 0C 78 56 34 12 01 07 44 47 78 0B 13 43 65 87 1E 6D
// coded string is:
// AA 55 9a 9a 66 56 aa 5a 95 6a 99 96 a5 9a a9 a6 aa a9 aa 95 9a 9a 9a 95 95 6a aa 65 a9 a5 a6 65 9A a9 99 95 69 69 a6 66 55
static const registerSetting_t preferredSettingsS2[] = {
    {CC120X_LNA,            0x03},  
    {CC120X_IOCFG2,         0x06}, //
    {CC120X_IOCFG0,         0x06},
 
    {CC120X_SYNC3,      0x55},
    {CC120X_SYNC2,      0x54},
    {CC120X_SYNC1,      0x76},
    {CC120X_SYNC0,      0x96},
    
    {CC120X_SYNC_CFG1,      0x6A},
    {CC120X_SYNC_CFG0,      0x23},
    {CC120X_DEVIATION_M,    0xAA},
    {CC120X_MODCFG_DEV_E,   0x04},    
    {CC120X_DCFILT_CFG,     0x4B},
    {CC120X_PREAMBLE_CFG1,  0x15},      //3 Bytes preamble, 0x55 55 55 + 3 Bytes SYNC
    {CC120X_PREAMBLE_CFG0,  0x8A},
    {CC120X_IQIC,           0xD8},
    {CC120X_CHAN_BW,        0x44},
    {CC120X_MDMCFG1,        0x72},    //0x42 + Manchester coding ENABLE + INVERT enable 0x72 =
    {CC120X_MDMCFG0,        0x05},   
    {CC120X_SYMBOL_RATE2,   0x8A},
    {CC120X_SYMBOL_RATE1,   0xD7},
    {CC120X_SYMBOL_RATE0,   0xF4},
    
    {CC120X_AGC_REF,        0x2A},
    {CC120X_AGC_CS_THR,     0xE3}, // 0xE3 = -110dBm = RX Sens. limit of 80% PER; EA=-103dBm or use E4 as in CC1200 Sniff example for 38.4kbps
    
//    {CC120X_AGC_CS_THR,     0xE8}, //F5=-110dBm or use F6=-109 ==> 23mA in office
    {CC120X_AGC_GAIN_ADJUST, 0x00},
    {CC120X_AGC_CFG3,       0xB1},
    {CC120X_AGC_CFG2,       0x20},       
    {CC120X_AGC_CFG1,       0x12},
    {CC120X_AGC_CFG0,       0x80},
        
    {CC120X_SETTLING_CFG,   0x03},
    
    {CC120X_FS_CFG,         0x12},
    {CC120X_WOR_CFG0,       0x20},
     
   // {CC120X_WOR_EVENT0_LSB, 0x22},      //gives 7.65mA in RX Sniff
    {CC120X_WOR_EVENT0_LSB, 0x1F},      //gives 8.34mA in RX Sniff and XOSC2=0x5
  //    {CC120X_WOR_EVENT0_LSB, 0x20},      //gives ?? mA in RX Sniff
  //  {CC120X_WOR_EVENT0_LSB, 0x18},  //3 Bytes preamble from SRF7; RX Sniff ==> 10.7mA 
    {CC120X_PKT_CFG2,       0x04},
 //   {CC120X_PKT_CFG1,       0x03}, //append status and CRC16 check
    {CC120X_PKT_CFG1,       0x01}, //append Yes, CRC16 check NO
    {CC120X_PKT_CFG0,       0x00}, //variable length mode
    {CC120X_RFEND_CFG0,     0x09},
    {CC120X_PKT_LEN,        0x15}, //21 Bytes
    
    {CC120X_IF_MIX_CFG,     0x1C},
    {CC120X_FREQOFF_CFG,    0x20},    
    {CC120X_TOC_CFG,        0x4E},
    
    {CC120X_MDMCFG2,        0x02},
    {CC120X_FREQ2,          0x56},
    {CC120X_FREQ1,          0xD4},
    {CC120X_FREQ0,          0x7A},
    {CC120X_IF_ADC1,        0xEE},
    {CC120X_IF_ADC0,        0x10},

    {CC120X_FS_DIG1,        0x07},
    {CC120X_FS_DIG0,        0xA5},
    {CC120X_FS_CAL1,        0x40},
    {CC120X_FS_CAL0,        0x0E},
    {CC120X_FS_DIVTWO,      0x03},
    {CC120X_FS_DSM0,        0x33},
    {CC120X_FS_DVC0,        0x17},
    {CC120X_FS_PFD,         0x00},
    {CC120X_FS_PRE,         0x6E},
    {CC120X_FS_REG_DIV_CML, 0x1C},
    {CC120X_FS_SPARE,       0xAC},
    {CC120X_FS_VCO0,        0xB5},
    {CC120X_IFAMP,          0x05},
    {CC120X_XOSC5,          0x0E},
    {CC120X_XOSC1,          0x03},
   
 //   {CC120X_XOSC2,          0x04},  //XTAL always ON if Bit1 =1 
   {CC120X_XOSC2,          0x05},  //XTAL always ON if Bit1 =1 

};

/*
Packet Example from EN13757-4:2012 for C-mode, NRZ coding
14 44 AE 0C 78 56 34 12 01 07 8C 20 27 78 0B 13 43 65 87 7A C5
*/
// RX filter BW = 12.500000 
// Address config = No address check 
// Packet length = 255 
// Symbol rate = 50kbps
// PA ramping = true 
// Performance mode = High Performance 
// Carrier frequency = 169.000000 
// Bit rate = 50kbps 
// Packet bit length = 0 
// Whitening = false 
// Manchester enable = false 
// Modulation format = 2-GFSK 
// Packet length mode = Variable 
// Device address = 0 
// TX power = 15 
// Deviation = 2.395630 
/*
SYNC3	54
SYNC2	3D
SYNC1	54
SYNC0	CD
SYNC_CFG1	A8
SYNC_CFG0	23
DEVIATION_M	47
MODCFG_DEV_E	B
DCFILT_CFG	56
PREAMBLE_CFG1	19
PREAMBLE_CFG0	8A
IQIC	C8
CHAN_BW	84
MDMCFG1	42
MDMCFG0	5
DRATE2	94
DRATE1	7A
DRATE0	E1
AGC_REF	27
AGC_CS_THR	F1
AGC_GAIN_ADJUST	0
AGC_CFG3	B1
AGC_CFG2	20
AGC_CFG1	11
AGC_CFG0	90
PKT_CFG2	0
PKT_CFG1	3
PKT_CFG0	0
PA_CFG1	7F
PA_CFG0	56
ASK_CFG	0F
PKT_LEN	3
IF_MIX_CFG	18
FREQOFF_CFG	20
TOC_CFG	3
MDMCFG2	2
MDM_TEST	0
IFAMP	5
FS_DIG0	AA

*/
static const registerSetting_t preferredSettingsC2other[]= 
{
    {CC120X_LNA,            0x03},       
    {CC120X_IOCFG2,         0x06}, //SYNC RX 
    {CC120X_IOCFG0,         0x06}, 
    {CC120X_SYNC3,      0x54},
    {CC120X_SYNC2,      0x3D},
    {CC120X_SYNC1,      0x54},
    {CC120X_SYNC0,      0xCD},
    {CC120X_SYNC_CFG1,      0xA8},
    {CC120X_SYNC_CFG0,      0x23},
    {CC120X_DEVIATION_M,    0x47},
    {CC120X_MODCFG_DEV_E,   0x0B},    
    {CC120X_DCFILT_CFG,     0x56},
    {CC120X_PREAMBLE_CFG1,  0x19},
    {CC120X_PREAMBLE_CFG0,  0x8A},
    {CC120X_IQIC,           0xC8},
    {CC120X_CHAN_BW,        0x84},
    {CC120X_MDMCFG1,        0x42},  //0x42, NO Invert, NO Manch.
    {CC120X_MDMCFG0,        0x05},   
    {CC120X_SYMBOL_RATE2,   0x94},
    {CC120X_SYMBOL_RATE1,   0x7A},
    {CC120X_SYMBOL_RATE0,   0xE1},
    {CC120X_AGC_REF,        0x27},  
    
    {CC120X_AGC_CS_THR,     0xF5}, //F5=-110dBm or use F6=-109 ==> 13.80mA
 //  {CC120X_AGC_CS_THR,     0x04}, //-95 ==> 23mA in office

    {CC120X_AGC_GAIN_ADJUST, 0x00},
    {CC120X_AGC_CFG3,       0xB1},
    {CC120X_AGC_CFG2,       0x20},       
    {CC120X_AGC_CFG1,       0x11},
    {CC120X_AGC_CFG0,       0x90},
        
    {CC120X_SETTLING_CFG,   0x03},
  
    {CC120X_FS_CFG,         0x12},
    {CC120X_WOR_CFG0,       0x20},
    {CC120X_WOR_EVENT0_LSB, 0x1C}, //RX Sniff 5Bytes preamble
    
    {CC120X_PKT_CFG2,       0x00}, //always CCA
    {CC120X_PKT_CFG1,       0x01}, //append Yes, CRC16 check NO
 //   {CC120X_PKT_CFG1,       0x03}, //append Yes, CRC16 check Y
    {CC120X_PKT_CFG0,       0x00}, 
    {CC120X_RFEND_CFG0,     0x09},
    {CC120X_PKT_LEN,        0x15},  //21 Bytes for C2-OTHER mode packet

    {CC120X_PA_CFG1, 0x7F},
    {CC120X_PA_CFG0, 0x56},

    
    {CC120X_IF_MIX_CFG,     0x18},
    {CC120X_FREQOFF_CFG,    0x20},    
    {CC120X_TOC_CFG,        0x03},
    
    {CC120X_MDMCFG2,        0x02},
    //
    {CC120X_FREQ2,          0x56},
    {CC120X_FREQ1,          0xF3}, //C2-meter
    {CC120X_FREQ0,          0xD7}, //C2-meter
    {CC120X_IF_ADC1,        0xEE},
    {CC120X_IF_ADC0,        0x10},
    
    
    {CC120X_FS_DIG1,        0x07},
    {CC120X_FS_DIG0,        0xAA}, //
    {CC120X_FS_CAL1,        0x40},
    {CC120X_FS_CAL0,        0x0E},
    {CC120X_FS_DIVTWO,      0x03},
    {CC120X_FS_DSM0,        0x33},
    {CC120X_FS_DVC0,        0x17},
    {CC120X_FS_PFD,         0x00},
    {CC120X_FS_PRE,         0x6E},
    {CC120X_FS_REG_DIV_CML, 0x1C},
    {CC120X_FS_SPARE,       0xAC},
    {CC120X_FS_VCO0,        0xB5},
    {CC120X_IFAMP,          0x05}, //
    {CC120X_XOSC5,          0x0E},
    {CC120X_XOSC1,          0x03},
    
    {CC120X_XOSC2,          0x04},  //XTAL always ON if Bit1 =1 
};

#ifdef  __cplusplus
}
#endif

#endif